@@ -148,6 +148,7 @@ static void cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, g
 static void cb_content_drag_data_get (GtkWidget * widget, GdkDragContext * dc, GtkSelectionData * data, guint info,
                                       guint timestamp, XfburnAudioComposition * content);
 static void cb_adding_done (XfburnAddingProgress *progress, XfburnAudioComposition *dc);
+static void cb_key_press_event (GtkWidget *widget, GdkEvent *event, XfburnAudioComposition *composition);
 
 /* thread entry points */
 static gpointer thread_add_files_cli (ThreadAddFilesCLIParams *params);
@@ -199,7 +200,7 @@ typedef struct
 static GtkHPanedClass *parent_class = NULL;
 static guint instances = 0;
 static gchar *did_warn = "Did warn about this already";
-static gchar trans_name[MAX_NAME_LENGTH] = {""};
+static gchar trans_name[MAX_NAME_LENGTH+1] = {""};
 
 static const GActionEntry actions[] = {
   {.name = "add-file", .activate = (gActionCallback)action_add_selected_files},
@@ -212,32 +213,6 @@ static const GActionEntry actions[] = {
 #endif /* CDTEXT */
 };
 
-static const GtkActionEntry action_entries[] = {
-  {"add-file", "list-add", N_("Add"), NULL, N_("Add the selected file(s) to the composition"),
-   G_CALLBACK (action_add_selected_files),},
-  {"remove-file", "list-remove", N_("Remove"), NULL, N_("Remove the selected file(s) from the composition"),
-   G_CALLBACK (action_remove_selection),},
-  {"clear", "edit-clear", N_("Clear"), NULL, N_("Clear the content of the composition"),
-   G_CALLBACK (action_clear),},
-  {"transcoder-info", "dialog-information", trans_name, NULL, N_("What files can get burned to an audio CD?"),
-   G_CALLBACK (action_info),},
-  //{"import-session", "xfburn-import-session", N_("Import"), NULL, N_("Import existing session"),},
-#if 0 /* CDTEXT */
-  {"rename-artist", "gtk-edit", N_("Rename Artist"), NULL, N_("Rename the artist of the selected file"),
-   G_CALLBACK (action_rename_selection_artist),},
-  {"rename-title", "gtk-edit", N_("Rename Title"), NULL, N_("Rename the title of the selected file"),
-   G_CALLBACK (action_rename_selection_title),},
-#endif /* CDTEXT */
-};
-
-static const gchar *toolbar_actions[] = {
-  "add-file",
-  "remove-file",
-  "clear",
-  "import-session",
-  "transcoder-info",
-};
-
 static GdkPixbuf *icon_directory = NULL, *icon_file = NULL;
 
 /********************************/
@@ -272,15 +247,10 @@ composition_interface_init (XfburnCompositionInterface *composition, gpointer if
 static void
 xfburn_audio_composition_init (XfburnAudioComposition * composition)
 {
+  gint x, y;
   XfburnAudioCompositionPrivate *priv = XFBURN_AUDIO_COMPOSITION_GET_PRIVATE (composition);
 
-  gtk_orientable_set_orientation(GTK_ORIENTABLE (composition), GTK_ORIENTATION_VERTICAL);
-
-  gint x, y;
-//  ExoToolbarsModel *model_toolbar;
-  gint toolbar_position;
   GtkWidget *hbox_toolbar;
-  //GtkWidget *hbox, *label;
   GtkWidget *scrolled_window;
   GtkTreeStore *model;
 #if 0 /* CDTEXT */
@@ -299,6 +269,8 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
                                 { "text/uri-list", 0, AUDIO_COMPOSITION_DND_TARGET_TEXT_URI_LIST },
                               };
 
+  gtk_orientable_set_orientation(GTK_ORIENTABLE (composition), GTK_ORIENTATION_VERTICAL);
+
   priv->full_paths_to_add = NULL;
   priv->trans = xfburn_transcoder_get_global ();
 
@@ -482,6 +454,10 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
   g_simple_action_set_enabled (action, FALSE);
 
   priv->warned_about = g_hash_table_new (g_direct_hash, g_direct_equal);
+
+  /* map delete key to remove file action */
+  g_signal_connect (G_OBJECT (priv->content), "key-press-event", G_CALLBACK (cb_key_press_event),
+                    composition);
 }
 
 static void
@@ -645,6 +621,7 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
     GtkWidget *menuitem_rename_artist;
     GtkWidget *menuitem_rename_title;
 #endif /* CDTEXT */
+    GdkRectangle r = {event->x, event->y, 1, 1};
 
     selection = gtk_tree_view_get_selection (treeview);
 
@@ -668,7 +645,6 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
     else
       gtk_widget_set_sensitive (menuitem_remove, FALSE);
 
-    GdkRectangle r = {event->x, event->y, 1, 1};
     gtk_menu_popup_at_rect (GTK_MENU (menu_popup),
         gtk_widget_get_parent_window (GTK_WIDGET (treeview)),
         &r, GDK_GRAVITY_SOUTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
@@ -821,6 +797,24 @@ cb_adding_done (XfburnAddingProgress *progress, XfburnAudioComposition *dc)
   xfburn_default_cursor (priv->content);
 }
 
+/**
+ * Handle the key-press-event on the audio composition interface.
+ *
+ * If the delete key was pressed, remove the currently-selected item.
+ */
+static void
+cb_key_press_event (GtkWidget *widget, GdkEvent *event, XfburnAudioComposition *composition)
+{
+  XfburnAudioCompositionPrivate *priv = XFBURN_AUDIO_COMPOSITION_GET_PRIVATE (composition);
+  guint keyval;
+
+  gdk_event_get_keyval (event, &keyval);
+
+  if (keyval == GDK_KEY_Delete) {
+    g_action_group_activate_action (G_ACTION_GROUP (priv->action_group), "remove-file", NULL);
+  }
+}
+
 #if 0 /* CDTEXT */
 static void
 action_rename_selection_artist (GtkAction * action, XfburnAudioComposition * dc)
@@ -967,38 +961,7 @@ action_add_selected_files (GSimpleAction * action, GVariant * param, XfburnAudio
   if (xfburn_settings_get_boolean("show-filebrowser", FALSE)) {
     selected_files = xfburn_file_browser_get_selection (browser);
   } else {
-    GtkWidget * dialog;
-
-    dialog = gtk_file_chooser_dialog_new (_("File(s) to add to composition"),
-                                          GTK_WINDOW(xfburn_main_window_get_instance()),
-                                          GTK_FILE_CHOOSER_ACTION_OPEN,
-                                          _("Add"),
-                                          GTK_RESPONSE_ACCEPT,
-                                          NULL);
-    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), TRUE);
-
-    if(xfburn_main_has_initial_dir ()) {
-      gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), xfburn_main_get_initial_dir ());
-    }
-
-    if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
-        GSList *list = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (dialog));
-        GString  * str = g_string_new(NULL);
-        GSList * curr;
-
-        for (curr = list; curr!=NULL; curr = curr->next) {
-            g_string_append(str, curr->data);
-            g_string_append_c(str, '\n');;
-        }
-
-        g_slist_free_full (list, g_free);
-        selected_files = str->str;
-        g_string_free (str, FALSE);
-        DBG("selected  files: %s ", selected_files);
-
-      //selected_files = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-    }
-    gtk_widget_destroy (dialog);
+    selected_files = xfburn_browse_for_files (FALSE);
   }
 
   if (selected_files) {
@@ -1462,6 +1425,7 @@ copy_entry_to (XfburnAudioComposition *dc, GtkTreeIter *src, GtkTreeIter *dest,
   GdkPixbuf *icon = NULL;
   gint pos = 0;
   gchar *name = NULL;
+  gint length = 0;
   guint64 size = 0;
   gchar *path = NULL;
   gchar *humanlength;
@@ -1479,6 +1443,7 @@ copy_entry_to (XfburnAudioComposition *dc, GtkTreeIter *src, GtkTreeIter *dest,
   gtk_tree_model_get (model, src,
                       AUDIO_COMPOSITION_COLUMN_POS, &pos,
                       AUDIO_COMPOSITION_COLUMN_CONTENT, &name,
+                      AUDIO_COMPOSITION_COLUMN_LENGTH, &length,
                       AUDIO_COMPOSITION_COLUMN_SIZE, &size,
                       AUDIO_COMPOSITION_COLUMN_PATH, &path,
                       AUDIO_COMPOSITION_COLUMN_HUMANLENGTH, &humanlength,
@@ -1522,6 +1487,7 @@ copy_entry_to (XfburnAudioComposition *dc, GtkTreeIter *src, GtkTreeIter *dest,
   gtk_tree_store_set (GTK_TREE_STORE (model), iter_new,
                       AUDIO_COMPOSITION_COLUMN_POS, pos,
                       AUDIO_COMPOSITION_COLUMN_CONTENT, name,
+                      AUDIO_COMPOSITION_COLUMN_LENGTH, length,
                       AUDIO_COMPOSITION_COLUMN_SIZE, size,
                       AUDIO_COMPOSITION_COLUMN_PATH, path,
                       AUDIO_COMPOSITION_COLUMN_HUMANLENGTH, humanlength,
@@ -1678,28 +1644,7 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
       if ((iter = copy_entry_to (composition, &iter_src, iter_prev, position)) != NULL) {
         GtkTreePath *path_parent = gtk_tree_path_copy (path_src);
 
-        if (gdk_drag_context_get_actions(dc) == GDK_ACTION_MOVE) {
-          /* remove source entry */
-          /*
-           * This shouldn't be able to happen anymore w/o folders
-          if (gtk_tree_path_up (path_parent) && path_where_insert &&
-              !gtk_tree_path_is_descendant (path_where_insert, path_parent)) {
-            // update parent size and humansize
-            GtkTreeIter iter_parent;
-            guint64 old_size;
-
-            gtk_tree_model_iter_parent (model, &iter_parent, &iter_src);
-            gtk_tree_model_get (model, &iter_parent, AUDIO_COMPOSITION_COLUMN_SIZE, &old_size, -1);
-
-            gtk_tree_store_set (GTK_TREE_STORE (model), &iter_parent,
-                                AUDIO_COMPOSITION_COLUMN_SIZE, old_size - size, -1);
-          }
-          */
-          gtk_tree_store_remove (GTK_TREE_STORE (model), &iter_src);
-
-        } else {
-          xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), secs);
-        }
+        gtk_tree_store_remove (GTK_TREE_STORE (model), &iter_src);
 
         gtk_tree_path_free (path_parent);
         g_free (iter_prev);
@@ -1904,10 +1849,11 @@ thread_add_files_drag (ThreadAddFilesDragParams *params)
 
       if (thread_add_file_to_list (composition, model, full_path, &iter, &iter_where_insert, position)) {
         if (position == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE
-            || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
+            || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER) {
           gdk_threads_enter ();
           gtk_tree_view_expand_row (GTK_TREE_VIEW (widget), priv->path_where_insert, FALSE);
           gdk_threads_leave ();
+        }
       }
 
     } else  {
