@@ -67,7 +67,6 @@ enum {
 };
 
 /* prototypes */
-static GObject * xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties);
 static void xfburn_burn_audio_cd_composition_dialog_finalize (GObject * object);
 
 static void xfburn_burn_audio_cd_composition_dialog_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec);
@@ -88,7 +87,7 @@ xfburn_burn_audio_cd_composition_dialog_class_init (XfburnBurnAudioCdComposition
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
-  
+
   // object_class->constructor = xfburn_burn_audio_cd_composition_dialog_constructor;
   object_class->finalize = xfburn_burn_audio_cd_composition_dialog_finalize;
   object_class->get_property = xfburn_burn_audio_cd_composition_dialog_get_property;
@@ -103,22 +102,17 @@ static void
 xfburn_burn_audio_cd_composition_dialog_init(XfburnBurnAudioCdCompositionDialog *obj)
 {
   XfburnBurnAudioCdCompositionDialogPrivate *priv = XFBURN_BURN_AUDIO_CD_COMPOSITION_DIALOG_GET_PRIVATE(obj);
-  
-  GdkPixbuf *icon = NULL;
+
   GtkBox *box;
   GtkWidget *frame;
   GtkWidget *vbox;
-  GtkWidget *align;
   GtkWidget *button;
-  //const char *comp_name;
 
   box = GTK_BOX (gtk_dialog_get_content_area((GTK_DIALOG (obj))));
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn Composition"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "stock_xfburn", GTK_ICON_SIZE_DIALOG, 0, NULL);
-  gtk_window_set_icon (GTK_WINDOW (obj), icon);
-  g_object_unref (icon);
+  gtk_window_set_icon_name (GTK_WINDOW (obj), "stock_xfburn");
 
   /* burning devices list */
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS |
@@ -263,9 +257,9 @@ typedef struct {
   gboolean burnfree;
 } ThreadBurnCompositionParams;
 
-static void 
+static void
 thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_drive *drive,
-                           struct burn_disc *disc, struct burn_session *session, int n_tracks, 
+                           struct burn_disc *disc, struct burn_session *session, int n_tracks,
                            int track_sectors[], struct burn_track **tracks, struct burn_source **srcs)
 {
   GtkWidget *dialog_progress = params->dialog_progress;
@@ -412,7 +406,7 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
     dialog_progress = xfburn_progress_dialog_new (GTK_WINDOW (dialog));
     gtk_window_set_transient_for (GTK_WINDOW (dialog_progress), gtk_window_get_transient_for (GTK_WINDOW (dialog)));
     gtk_widget_hide (GTK_WIDGET (dialog));
-    
+
     gtk_widget_show (dialog_progress);
 
     device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
@@ -441,6 +435,6 @@ xfburn_burn_audio_cd_composition_dialog_new (GSList *track_list)
   XfburnBurnAudioCdCompositionDialog *obj;
 
   obj = XFBURN_BURN_AUDIO_CD_COMPOSITION_DIALOG (g_object_new (XFBURN_TYPE_BURN_AUDIO_CD_COMPOSITION_DIALOG, "track-list", track_list, NULL));
-  
+
   return GTK_WIDGET (obj);
 }
