@@ -126,20 +126,15 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   GtkBox *box = GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (obj)));
   XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (obj);
 
-  GdkPixbuf *icon = NULL;
   GtkFileFilter *filter;
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *button;
-  gint x,y;
   XfburnDevice *device;
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn image"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
-  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
-  gtk_window_set_icon (GTK_WINDOW (obj), icon);
-  g_object_unref (icon);
+  gtk_window_set_icon_name (GTK_WINDOW (obj), "stock_xfburn");
 
   /* file */
   priv->chooser_image = gtk_file_chooser_button_new (_("Image to burn"), GTK_FILE_CHOOSER_ACTION_OPEN);
@@ -471,7 +466,7 @@ check_burn_button (XfburnBurnImageDialog * dialog)
   filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (priv->chooser_image));
   if (filename != NULL) {
     if (last_file)
-        g_free (last_file);
+      g_free (last_file);
     last_file = filename;
     gtk_widget_set_sensitive (priv->burn_button, valid_disc);
   } else {
