@@ -1,4 +1,3 @@
-/* $Id: xfburn-create-iso-progress-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -48,8 +47,8 @@ typedef struct
   /* Add Signal Functions Here */
 } XfburnCreateIsoProgressDialogClass;
 
-GType xfburn_create_iso_progress_dialog_get_type ();
-GtkWidget *xfburn_create_iso_progress_dialog_new ();
+GType xfburn_create_iso_progress_dialog_get_type (void);
+GtkWidget *xfburn_create_iso_progress_dialog_new (void);
 
 G_END_DECLS
 
