@@ -55,9 +55,6 @@ typedef struct {
 
   GtkWidget *file_browser;
   GtkWidget *compositions_notebook;
-
-  gboolean support_cdr;
-  gboolean support_cdrw;
 } XfburnMainWindowPrivate;
 
 /* prototypes */
@@ -114,82 +111,10 @@ static const GActionEntry action_entries[] = {
   { .name = "burn-dvd", .activate = (gActionCallback)action_burn_dvd_image},
 };
 
-static const struct {
-  const gchar * target;
-  const gchar * accel[2];
-} accelerator[] = {
-  {"new-data-composition",{"<Control><Alt>e",NULL}},
-  {"new-audio-composition",{"<Control><Alt>A",NULL}},
-};
-
-/*static const GtkActionEntry action_entries[] = {
-  {"file-menu", NULL, N_("_File"), NULL, NULL, NULL},
-  /*{"new-composition", "document-new", N_("_New composition"), "", N_("Create a new composition"),},*/
-  /*{"new-composition", "document-new", N_("_New composition"), NULL, N_("Create a new composition"),
-    G_CALLBACK (action_new_data_composition),}, */
-/*  {"new-data-composition", "xfburn-new-data-composition", N_("New data composition"), "<Control><Alt>e", N_("New data composition"),
-    G_CALLBACK (action_new_data_composition),},
-  {"new-audio-composition", "xfburn-audio-cd", N_("New audio composition"), "<Control><Alt>A", N_("New audio composition"),
-    G_CALLBACK (action_new_audio_composition),},
-  /*{"load-composition", "document-open", N_("Load composition"), NULL, N_("Load composition"),
-   G_CALLBACK (action_load),},
-  {"save-composition", "document-save", N_("Save composition"), NULL, N_("Save composition"),
-   G_CALLBACK (action_save),},
-  {"save-composition-as", "document-save"_AS, N_("Save composition as..."), NULL, N_("Save composition as"),
-   G_CALLBACK (action_save_as),},*/
-/*  {"close-composition", "window-close", N_("Close composition"), NULL, N_("Close composition"),
-   G_CALLBACK (action_close),},
-  {"quit", "application-exit", N_("_Quit"), NULL, N_("Quit Xfburn"), G_CALLBACK (action_quit),},
-  {"edit-menu", NULL, N_("_Edit"), NULL, NULL, NULL},
-  {"preferences", "preferences-system", N_("Prefere_nces"), NULL, N_("Show preferences dialog"),
-   G_CALLBACK (action_preferences),},
-  {"action-menu", NULL, N_("_Actions"), NULL, NULL, NULL},
-  {"view-menu", NULL, N_("_View"), NULL, NULL, NULL},
-  {"refresh", "view-refresh", N_("Refresh"), NULL, N_("Refresh file list"),
-   G_CALLBACK (action_refresh_directorybrowser),},
-  {"help-menu", NULL, N_("_Help"), NULL, NULL, NULL},
-  {"about", "gtk-about", N_("_About"), NULL, N_("Display information about Xfburn"),
-   G_CALLBACK (action_about),},
-  {"blank-disc", "xfburn-blank-cdrw", N_("Blank CD-RW"), NULL, N_("Blank CD-RW"),
-   G_CALLBACK (action_blank),},
-  {"copy-data", "xfburn-data-copy", N_("Copy Data CD"), NULL, N_("Copy Data CD"),
-   G_CALLBACK (action_copy_cd),},
-  /*{"copy-audio", "xfburn-audio-copy", N_("Copy Audio CD"), NULL, N_("Copy Audio CD"),}, */
-/*  {"burn-image", "stock_xfburn", N_("Burn Image"), NULL, N_("Burn Image"),
-   G_CALLBACK (action_burn_image),},
-/*  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
-   G_CALLBACK (action_copy_dvd),}, */
-/*  {"burn-dvd", "xfburn-burn-image", N_("Burn DVD Image"), NULL, N_("Burn DVD Image"),
-   G_CALLBACK (action_burn_dvd_image),},
-};
-*/
 static const GActionEntry toggle_action_entries[] = {
   { .name = "show-filebrowser", .state = "false", .change_state = (gActionCallback)action_show_filebrowser },
   { .name = "show-toolbar", .state = "false", .change_state = (gActionCallback)action_show_toolbar },
 };
-/* static const GtkToggleActionEntry toggle_action_entries[] = {
-  {"show-filebrowser", NULL, N_("Show file browser"), NULL, N_("Show/hide the file browser"),
-   G_CALLBACK (action_show_filebrowser), TRUE,},
-  {"show-toolbar", NULL, N_("Show toolbar"), NULL, N_("Show/hide the toolbar"),
-   G_CALLBACK (action_show_toolbar), TRUE,},
-}; */
-
-static const gchar *toolbar_actions[] = {
-  "new-data-composition",
-  "new-audio-composition",
-/*  "load-composition",
-  "save-composition",
-  "close-composition",*/
-  "blank-disc",
-  "copy-data",
-  //"copy-audio",
-  "burn-image",
-  "copy-dvd",
-  "burn-dvd",
-  "refresh",
-  "about",
-  "preferences",
-};
 
 static XfburnMainWindow *instance = NULL;
 
@@ -218,17 +143,17 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (mainwin);
 
-  GtkAccelGroup *accel_group;
   gchar *file;
 
   GtkWidget *vbox;
+  GMenuModel *menu_model;
 
   /* the window itself */
   gtk_window_set_position (GTK_WINDOW (mainwin), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_title (GTK_WINDOW (mainwin), "Xfburn");
   gtk_window_set_icon_name (GTK_WINDOW (mainwin), "stock_xfburn");
-  gtk_window_resize (GTK_WINDOW (mainwin), xfburn_settings_get_int ("main-window-width", 850),
-		     xfburn_settings_get_int ("main-window-height", 700));
+  gtk_window_resize (GTK_WINDOW (mainwin), xfburn_settings_get_int ("main-window-width", 790),
+		     xfburn_settings_get_int ("main-window-height", 500));
 
   g_signal_connect (G_OBJECT (mainwin), "delete-event", G_CALLBACK (cb_delete_main_window), priv);
 
@@ -266,8 +191,8 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   gtk_widget_show (vbox);
 
   /* menubar */
-  GMenuModel *menu_model = (GMenuModel*)gtk_builder_get_object (priv->ui_manager, "main-menu");
-  
+  menu_model = (GMenuModel*)gtk_builder_get_object (priv->ui_manager, "main-menu");
+
   priv->menubar = gtk_menu_bar_new_from_model (menu_model);
   if (G_LIKELY (priv->menubar != NULL)) {
     gtk_widget_insert_action_group (priv->menubar, "app", G_ACTION_GROUP (priv->action_map));
@@ -513,8 +438,6 @@ action_quit (GAction * action, GVariant* param, XfburnMainWindow * window)
 static void
 action_about (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
-  gint x, y;
-  GdkPixbuf *icon = NULL;
   const gchar *auth[] = { "David Mohr david@mcbf.net Author/Maintainer",
 			  "Mario Đanić mario@libburnia-project.org Author/Maintainer",
 			  "Jean-François Wauthy pollux@xfce.org Retired author/maintainer",
@@ -554,31 +477,21 @@ action_about (GAction * action, GVariant* param, XfburnMainWindow * window)
     "正龙 赵 longer.zhao@gmail.com zh_CN\n"
     "Cosmo Chene cosmolax@gmail.com zh_TW\n";
 
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
-  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
-  if (!icon)
-    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-cdrom", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
-  if (!icon)
-    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
-
 #if !GTK_CHECK_VERSION (2, 18, 0)
   gtk_about_dialog_set_email_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
   gtk_about_dialog_set_url_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
 #endif
   gtk_show_about_dialog(GTK_WINDOW (window),
-		  "logo", icon,
+		  "logo-icon-name", "media-optical",
 		  "program-name", "Xfburn",
 		  "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
 		  "version", VERSION,
 		  "comments", _("Another cd burning GUI"),
-		  "website", "https://docs.xfce.org/apps/xfburn",
+		  "website", "https://docs.xfce.org/apps/xfburn/start",
 		  "copyright", "2005-2008 David Mohr, Mario Đanić, Jean-François Wauthy",
 		  "authors", auth,
 		  "translator-credits", translators,
 		  NULL);
-
-  if (G_LIKELY (icon != NULL))
-    g_object_unref (G_OBJECT (icon));
 }
 
 static void
@@ -604,12 +517,15 @@ action_refresh_directorybrowser (GAction * action, GVariant* param, XfburnMainWi
 static void
 action_show_filebrowser (GSimpleAction * action, GVariant* value, XfburnMainWindow * window)
 {
+  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
+  GAction *file;
+  gboolean toggle;
+
   if(g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
     g_simple_action_set_state (action, value);
 
-  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  GAction *file = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-filebrowser");
-  gboolean toggle = g_variant_get_boolean  (g_action_get_state (file));
+  file = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-filebrowser");
+  toggle = g_variant_get_boolean  (g_action_get_state (file));
   xfburn_settings_set_boolean ("show-filebrowser", toggle);
 
   if ( toggle ) {
@@ -623,11 +539,15 @@ action_show_filebrowser (GSimpleAction * action, GVariant* value, XfburnMainWind
 static void
 action_show_toolbar (GSimpleAction * action, GVariant* value, XfburnMainWindow * window)
 {
+  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
+  GAction *tool;
+  gboolean toggle;
+
   if(g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
     g_simple_action_set_state (action, value);
-  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  GAction *tool = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-toolbar");
-  gboolean toggle = g_variant_get_boolean (g_action_get_state (tool));
+
+  tool = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-toolbar");
+  toggle = g_variant_get_boolean (g_action_get_state (tool));
 
   xfburn_settings_set_boolean ("show-toolbar", toggle);
 
@@ -660,8 +580,6 @@ xfburn_main_window_new (void)
     XfburnMainWindowPrivate *priv;
     GAction *action;
     GActionMap *action_map;
-    GList *device = NULL;
-    XfburnDeviceList *devlist;
 
     instance = win = XFBURN_MAIN_WINDOW (obj);
     priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (win);
@@ -674,40 +592,6 @@ xfburn_main_window_new (void)
    /* action = gtk_action_group_get_action (priv->action_group, "save-composition");
     gtk_action_set_sensitive (GTK_ACTION (action), FALSE);*/
 
-    /* disable action that cannot be used due to device */
-
-    devlist = xfburn_device_list_new ();
-    g_object_get (G_OBJECT (devlist), "devices", &device, NULL);
-    g_object_unref (devlist);
-
-    /* FIXME: this is really outdated behavior. Needs to get rewritten */
-    while (device != NULL) {
-      XfburnDevice *device_info = (XfburnDevice *) device->data;
-      gboolean cdr, cdrw;
-
-      g_object_get (G_OBJECT (device_info), "cdr", &cdr, "cdrw", &cdrw, NULL);
-
-      if (cdr)
-        priv->support_cdr = TRUE;
-      if (cdrw)
-        priv->support_cdrw = TRUE;
-
-      device = g_list_next (device);
-    }
-
-    if (!priv->support_cdr) {
-      action = g_action_map_lookup_action (action_map, "copy-data");
-      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
-      action = g_action_map_lookup_action (action_map, "copy-audio");
-      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
-      action = g_action_map_lookup_action (action_map, "burn-image");
-      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
-    }
-    if (!priv->support_cdrw) {
-      action = g_action_map_lookup_action (action_map, "blank-disc");
-      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
-    }
-
     /* show welcome tab */
     xfburn_compositions_notebook_add_welcome_tab (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), action_map);
   }
@@ -764,19 +648,3 @@ xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, i
   filelist = xfburn_make_abosulet_file_list (filec, filenames);
   xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filelist);
 }
-
-gboolean
-xfburn_main_window_support_cdr (XfburnMainWindow *window)
-{
-  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-
-  return priv->support_cdr;
-}
-
-gboolean
-xfburn_main_window_support_cdrw (XfburnMainWindow *window)
-{
-  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-
-  return priv->support_cdrw;
-}
