@@ -5,12 +5,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -39,12 +39,12 @@ G_BEGIN_DECLS
 
 typedef void (* gActionCallback) (GSimpleAction *,GVariant *,gpointer);
 
-typedef struct 
+typedef struct
 {
   GtkWindow window;
 } XfburnMainWindow;
 
-typedef struct 
+typedef struct
 {
   GtkWindowClass parent_class;
 } XfburnMainWindowClass;
@@ -60,8 +60,5 @@ XfburnFileBrowser *xfburn_main_window_get_file_browser (XfburnMainWindow *window
 void xfburn_main_window_add_data_composition_with_files (XfburnMainWindow *window, int filec, char **filenames);
 void xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, int filec, char **filenames);
 
-gboolean xfburn_main_window_support_cdr (XfburnMainWindow *window);
-gboolean xfburn_main_window_support_cdrw (XfburnMainWindow *window);
-
 G_END_DECLS
 #endif
