@@ -120,7 +120,7 @@ xfburn_main_enter_main_window (void)
 
 
 const gchar *
-xfburn_main_get_initial_dir ()
+xfburn_main_get_initial_dir (void)
 {
   if (initial_dir)
     return initial_dir;
@@ -129,7 +129,7 @@ xfburn_main_get_initial_dir ()
 }
 
 gboolean
-xfburn_main_has_initial_dir ()
+xfburn_main_has_initial_dir (void)
 {
   if (initial_dir)
     return TRUE;
@@ -191,7 +191,7 @@ main (int argc, char **argv)
   XfburnTranscoder *transcoder;
   XfburnDeviceList *devlist;
 
-#if DEBUG > 0
+#ifdef DEBUG
   /* I have to disable this until GtkTreeView gets fixed,
    * and doesn't complain anymore when a DnD doesn't add any
    * rows
@@ -269,7 +269,7 @@ main (int argc, char **argv)
 
   DBG ("%s version %s for Xfce %s\n", PACKAGE, VERSION, xfce_version_string ());
 
-  xfburn_settings_init ();
+  xfburn_settings_init_external ();
 
 #ifdef HAVE_GUDEV
   error_msg = xfburn_udev_manager_create_global ();
@@ -294,7 +294,6 @@ main (int argc, char **argv)
                                     ((const gchar *) _("No burners are currently available")));
     gtk_message_dialog_format_secondary_text (dialog,
                                     _("Possibly the disc(s) are in use, and cannot get accessed.\n\n"
-                                      "Please unmount and restart the application.\n\n"
                                       "If no disc is in the drive, check that you have read and write access to the drive with the current user."));
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (GTK_WIDGET (dialog));
