@@ -52,7 +52,7 @@
 #include "xfburn-audio-track-gst.h"
 
 
-/* 
+/*
  * Don't define it for no debugging output (don't set to 0, I was too lazy to clean up).
  * Set DEBUG_GST >= 1 to be able to inspect the data just before it gets to the fd,
  *                    and to get a lot more gst debugging output.
@@ -87,7 +87,7 @@ static gboolean is_initialized (XfburnTranscoder *trans, GError **error);
 static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data);
 static void on_pad_added (GstElement *element, GstPad *pad, gpointer data);
 
-#ifdef DEBUG_GST
+#if DEBUG_GST > 2
 static void cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data);
 #endif
 
@@ -95,7 +95,7 @@ static void cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data);
 
 enum {
   LAST_SIGNAL,
-}; 
+};
 
 typedef enum {
   XFBURN_TRANSCODER_GST_STATE_IDLE,
@@ -137,17 +137,17 @@ typedef struct {
 #define XFBURN_AUDIO_TRACK_GET_GST(atrack) ((XfburnAudioTrackGst *) (atrack)->data)
 
 /* globals */
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
 static guint64 total_size = 0;
 #endif
 
-static const gchar *errormsg_gst_setup = "An error occurred setting gstreamer up for transcoding";
-static const gchar *errormsg_libburn_setup = "An error occurred while setting the burning backend up";
-static const gchar *errormsg_missing_plugin = "%s is missing.\n"
+static const gchar *errormsg_gst_setup = N_("An error occurred setting gstreamer up for transcoding");
+static const gchar *errormsg_libburn_setup = N_("An error occurred while setting the burning backend up");
+static const gchar *errormsg_missing_plugin = N_("%s is missing.\n"
                                               "\n"
                                               "You do not have a decoder installed to handle this file.\n"
                                               "Probably you need to look at the gst-plugins-* packages\n"
-                                              "for the necessary plugins.\n";
+                                              "for the necessary plugins.\n");
 
 /*********************/
 /* class declaration */
@@ -168,7 +168,7 @@ static void
 xfburn_transcoder_gst_class_init (XfburnTranscoderGstClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  
+
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize = xfburn_transcoder_gst_finalize;
@@ -231,13 +231,13 @@ transcoder_interface_init (XfburnTranscoderInterface *iface, gpointer iface_data
 /* internals */
 /*           */
 
-static void 
+static void
 create_pipeline (XfburnTranscoderGst *trans)
 {
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
 
   GstElement *pipeline, *source, *decoder, *resample, *conv1, *conv2, *sink;
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
   GstElement *id;
 #endif
   GstBus *bus;
@@ -252,7 +252,7 @@ create_pipeline (XfburnTranscoderGst *trans)
   priv->conv1    = conv1    = gst_element_factory_make ("audioconvert",  "converter1");
   priv->resample = resample = gst_element_factory_make ("audioresample", "resampler");
   priv->conv2    = conv2    = gst_element_factory_make ("audioconvert",  "converter2");
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
                   id       = gst_element_factory_make ("identity",      "debugging-identity");
 #endif
   priv->sink    = sink     = gst_element_factory_make ("fdsink",        "audio-output");
@@ -266,7 +266,7 @@ create_pipeline (XfburnTranscoderGst *trans)
     return;
   }
 
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
   if (!id) {
     g_warning ("The debug identity element could not be created");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
@@ -284,7 +284,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 
   gst_bin_add_many (GST_BIN (pipeline),
                     source, decoder, conv1, resample, conv2, sink, NULL);
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
   gst_bin_add (GST_BIN (pipeline), id);
 #endif
 
@@ -299,7 +299,7 @@ create_pipeline (XfburnTranscoderGst *trans)
             "format", G_TYPE_STRING, "S16LE",
             NULL);
 
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 0 && defined (DEBUG)
   // TODO without the filter it does work but I'm not sure the audio format is correct
   if (!gst_element_link_filtered (conv2, id, caps)) {
 #else
@@ -313,7 +313,7 @@ create_pipeline (XfburnTranscoderGst *trans)
     return;
   }
   gst_caps_unref (caps);
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 2 && defined (DEBUG)
   gst_element_link (id, sink);
   g_signal_connect (id, "handoff", G_CALLBACK (cb_handoff), id);
 #endif
@@ -321,7 +321,7 @@ create_pipeline (XfburnTranscoderGst *trans)
   g_signal_connect (decoder, "pad-added", G_CALLBACK (on_pad_added), trans);
 }
 
-static void 
+static void
 delete_pipeline (XfburnTranscoderGst *trans)
 {
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
@@ -331,7 +331,7 @@ delete_pipeline (XfburnTranscoderGst *trans)
 #endif
   if (gst_element_set_state (priv->pipeline, GST_STATE_NULL) == GST_STATE_CHANGE_FAILURE)
     g_warning ("Failed to change state to null, deleting pipeline anyways");
-  
+
   /* give gstreamer a chance to do something
    * this might not be necessary, but shouldn't hurt */
   g_thread_yield ();
@@ -340,7 +340,7 @@ delete_pipeline (XfburnTranscoderGst *trans)
   priv->pipeline = NULL;
 }
 
-static void 
+static void
 recreate_pipeline (XfburnTranscoderGst *trans)
 {
   delete_pipeline (trans);
@@ -384,7 +384,7 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
       XfburnAudioTrackGst *gtrack = XFBURN_AUDIO_TRACK_GET_GST (priv->curr_track);
 
 #if DEBUG_GST > 0
-  #if DEBUG > 0
+  #if defined (DEBUG)
       DBG ("End of stream, wrote %.0f bytes", (gfloat) total_size);
   #else
       g_message ("End of stream.");
@@ -495,8 +495,10 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
 
           g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_MISSING_PLUGIN,
                        _(errormsg_missing_plugin),
-                        gst_missing_plugin_message_get_description (msg)); 
+                        gst_missing_plugin_message_get_description (msg));
       }
+
+      break;
     }
     default:
 #if DEBUG_GST == 1
@@ -539,17 +541,17 @@ on_pad_added (GstElement *element, GstPad *pad, gpointer data)
     GstMessage *msg;
     GstBus *bus;
 
-    gchar *error_msg = "File content has a decoder but is not audio.";
+    const gchar *error_msg = N_("File content has a decoder but is not audio.");
 
     DBG ("%s", error_msg);
-    
+
     gst_caps_unref (caps);
     gst_object_unref (audiopad);
 
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_NO_AUDIO,
 		    "%s",
                  _(error_msg));
-    
+
     msg_struct = gst_structure_new_empty ("no-audio-content");
 
     msg = gst_message_new_application (GST_OBJECT (element), msg_struct);
@@ -570,7 +572,7 @@ on_pad_added (GstElement *element, GstPad *pad, gpointer data)
 }
 
 
-static const gchar * 
+static const gchar *
 get_name (XfburnTranscoder *trans)
 {
   /* Note to translators: you can probably keep this as gstreamer,
@@ -579,7 +581,7 @@ get_name (XfburnTranscoder *trans)
   return _("gstreamer");
 }
 
-static const gchar * 
+static const gchar *
 get_description (XfburnTranscoder *trans)
 {
   return _("The gstreamer transcoder uses the gstreamer\n"
@@ -592,7 +594,7 @@ get_description (XfburnTranscoder *trans)
            "gstreamer plugin packages installed.");
 }
 
-#if DEBUG_GST > 0 && DEBUG > 0
+#if DEBUG_GST > 2 && defined (DEBUG)
 
 /* this function can inspect the data just before it is passed on
    to the fd for processing by libburn */
@@ -600,20 +602,18 @@ static void
 cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data)
 {
   guint size = gst_buffer_get_size (buffer);
-#if DEBUG_GST > 2
   static int i = 0;
   const int step = 30;
-#endif
 
   total_size += size;
-#if DEBUG_GST > 2
   if (++i % step == 0)
     DBG ("gstreamer just processed ~%6d bytes (%8.0f bytes total).", size*step, (float)total_size);
-#endif
 }
 
 #endif
 
+#ifdef DEBUG
+
 static gchar *
 get_discoverer_required_plugins_message (GstDiscovererInfo *info)
 {
@@ -624,9 +624,9 @@ get_discoverer_required_plugins_message (GstDiscovererInfo *info)
   plugins = (gchar **) gst_discoverer_info_get_missing_elements_installer_details (info);
 
   if (g_strv_length(plugins) == 0) {
-    str = g_string_new ("No information available on which plugin is required.");
+    str = g_string_new (_("No information available on which plugin is required."));
   } else {
-    str = g_string_new("Required plugins: ");
+    str = g_string_new (_("Required plugins: "));
     plugins_str = g_strjoinv (", ", plugins);
     g_string_append (str, plugins_str);
     g_free (plugins_str);
@@ -635,6 +635,8 @@ get_discoverer_required_plugins_message (GstDiscovererInfo *info)
   return g_string_free (str, FALSE);
 }
 
+#endif
+
 static gboolean
 get_audio_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
@@ -724,7 +726,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
 {
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
-  
+
   struct burn_track *track;
 
   XfburnAudioTrackGst *gtrack = XFBURN_AUDIO_TRACK_GET_GST (atrack);
@@ -751,7 +753,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
     close (pipe_fd[0]);  close (pipe_fd[1]);
     return NULL;
   }
-  
+
   /* install fifo,
     * its size will be a bit bigger in audio mode but that shouldn't matter */
   src_fifo = burn_fifo_source_new (atrack->src, AUDIO_BYTES_PER_SECTOR, xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE) / 2, 0);
@@ -760,7 +762,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
 
 
   track = burn_track_create ();
-  
+
   if (burn_track_set_source (track, atrack->src) != BURN_SOURCE_OK) {
     g_warning ("Could not add source to track %s.", atrack->inputfile);
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_BURN_SOURCE,
@@ -856,7 +858,7 @@ transcode_next_track (XfburnTranscoderGst *trans, GError **error)
   return TRUE;
 }
 
-static void 
+static void
 finish (XfburnTranscoder *trans)
 {
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
@@ -890,7 +892,7 @@ finish (XfburnTranscoder *trans)
     recreate_pipeline (gst);
     return;
   }
-  
+
   if ((state != GST_STATE_READY) &&
       (gst_element_set_state (priv->pipeline, GST_STATE_NULL) == GST_STATE_CHANGE_FAILURE)) {
     DBG ("Could not make pipeline ready, recreating it");
@@ -903,7 +905,7 @@ finish (XfburnTranscoder *trans)
 }
 
 
-static gboolean 
+static gboolean
 is_initialized (XfburnTranscoder *trans, GError **error)
 {
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
